==> haskell-isomorphism-class-0.1.0.12-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.0.12
visibility:           public
id:                   isomorphism-class-0.1.0.12-AdMg4noi2704EXG2Ghnfix
key:                  isomorphism-class-0.1.0.12-AdMg4noi2704EXG2Ghnfix
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  284bec16526460d25a737a53e3774b56
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.0.12-AdMg4noi2704EXG2Ghnfix
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-9MfualSpDNWnshBkTCGL2
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ text-2.0.2
    unordered-containers-0.2.20-GHxywVRZMTgDKQfzKfhJsl
    vector-0.13.2.0-7lCcQdq9xkO6clGWLwrFQw

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.0.12-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isomorphism-class
version:              0.1.0.12
visibility:           public
id:                   isomorphism-class-0.1.0.12-3JteOIrND6JHRgvdMy5fnk
key:                  isomorphism-class-0.1.0.12-3JteOIrND6JHRgvdMy5fnk
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  c14fffe4be75db8c6483e0bd45b235a5
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/isomorphism-class-0.1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.0.12-3JteOIrND6JHRgvdMy5fnk
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX
    primitive-0.8.0.0-2MtTSGoMYmP3ESqdIhZDu7 text-2.0.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
